###########################################################
### Ch3 - Script 2 - Initial Screening and Flowering Time
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### Screening graphs
###########################################################
screening_graph <- FTdata %>% 
  filter(sowing_number %in% c("P717", "P725")) %>% 
  mutate(photo = if_else(sowing_number == "P717" & plant_num == 2,
                         TRUE, FALSE), 
         genotype = if_else(genotype == "R108", "Wild-type (R108)", genotype)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = genotype)) +
  stat_ellipse(data = FTdata %>% 
                 filter(sowing_number == "P725") %>% 
                 mutate(genotype = if_else(genotype == "R108", "Wild-type (R108)", genotype)),
               size = 1,
               alpha = 0.6) +
  geom_jitter(size = 3, alpha = 0.9) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  scale_x_continuous(limits = c(0, 80), expand = c(0, 0)) +
  scale_y_continuous(limits = c(0, 20), expand = c(0, 0)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.2, .9),
        legend.text = element_text(size = 22),
        axis.text = element_text(size = 18),
        axis.title.y = element_text(size = 22),
        axis.title.x = element_text(vjust = -1, size = 22))

###########################################################
### Flowering time
###
###             NF1634 R108 
###  LD         P912   P913 
###  SD         P908   P909 
###  VLD        Q151   Q156 
###  VSD        Q152   Q154 
###########################################################
flowering_graph <- FTdata %>% 
  filter(sowing_number %in% c("P908", "P909", 
                              "P912", "P913", 
                              "Q151", "Q152", 
                              "Q154", "Q156")) %>% 
  mutate(genotype = if_else(genotype == "R108", "Wild-type (R108)", genotype)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = genotype)) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(3, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  facet_wrap( ~ conditions, nrow = 2,) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 120)) + 
  scale_y_continuous(expand = c(0, 0)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.06, .93),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2))


###########################################################
### Flowering time - Linkage
###
###            F2 Pop.      Wild-type
### Batch 1    Q148, Q149   Q155
### Batch 2    Q236         Q235
###########################################################
FTdata %>% 
  filter(sowing_number %in% c("Q148", "Q149", "Q155", "Q236", "Q235"),
         !is.na(days_to_flower),
         !(sowing_number == "Q236" & mutant == 'Wild-type segregant')) %>% 
  mutate(batch = if_else(sowing_date == "29/08/16", "Batch 1", "Batch 2"),
         mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant)) %>% 
  ggplot(aes(days_to_flower, node_num, colour = fct_relevel(mutant, 'Wild-type (R108)', after=2) )) +
  geom_jitter(size = 2, alpha = 0.6) +
  scale_colour_manual(values = g_colours[c(9, 10, 2)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  geom_jitter(data = FTdata %>% 
                filter(sowing_number == "Q236" & mutant == 'Wild-type segregant'),
              size = 2, alpha = 0.6) +
  facet_grid(. ~ batch) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 50)) + 
  scale_y_continuous(expand = c(0, 0), limits = c(0, 15)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.13, .91),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(4, "lines"),
        axis.title.x = element_text(vjust = -2)) 

ggsave("Ch3_NF1634_linkage.png", width = 265, height = 129, units = 'mm')
