###########################################################
### Ch3 - Script 4 - Calculations
###########################################################

###########################################################
### Flowering time
###
###             NF1634 R108 
###  LD         P912   P913 
###  SD         P908   P909 
###  VLD        Q151   Q156 
###  VSD        Q152   Q154 
###########################################################
FTdata %>% 
  filter(sowing_number %in% c("P908", "P909", 
                              "P912", "P913", 
                              "Q151", "Q152", 
                              "Q154", "Q156")) %>% 
  flr_summary() %>% 
  arrange(conditions, genotype)

# Days
FTdata %>% 
  filter(sowing_number %in% c("P908", "P909", 
                              "P912", "P913", 
                              "Q151", "Q152", 
                              "Q154", "Q156")) %>% 
  flr_summary() %>% 
  select(genotype, conditions, days_to_flower_mean) %>% 
  spread(genotype, days_to_flower_mean) %>% 
  mutate(difference = NF1634-R108, percentDifferent = (NF1634/R108)-1)

# Nodes
FTdata %>% 
  filter(sowing_number %in% c("P908", "P909", 
                              "P912", "P913", 
                              "Q151", "Q152", 
                              "Q154", "Q156")) %>% 
  flr_summary() %>% 
  select(genotype, conditions, node_num_mean) %>% 
  spread(genotype, node_num_mean) %>% 
  mutate(difference = NF1634-R108, percentDifferent = (NF1634/R108)-1)
###########################################################
### Gene Expression
###
### Late Flowering NF1634             P866 and P867
### Wild-type like flowering NF1634   P864 and P865
### Wild-type                         P869
###########################################################

# Primer pair B
gene_expr %>% 
  filter(date == "03/06/16") %>%
  rt_calc() 

# Primer pair C
gene_expr %>% 
  filter(date == "04/04/17") %>% 
  rt_calc()

###########################################################
### Linkage - Chi Squared goodness of fit 
###           (inheritance of phenotype)
###            F2 Pop.      Wild-type
### Batch 1    Q148, Q149   Q155
### Batch 2    Q236         Q235
###########################################################
FTdata %>% 
  filter(sowing_number %in% c("Q148", "Q149", "Q155", "Q236", "Q235")) %>% 
  group_by(sowing_date) %>% 
  nest() %>% 
  mutate(data = map2(data, sowing_date, ~ mutate(.x, sowing_date = .y) %>% 
                       select(1:5, 12, 6:11)),
    summary = map(data, ~ flr_summary(.x, group=mutant))) %>%
  mutate(batch = if_else(sowing_date == "29/08/16", "Batch 1", "Batch 2")) %>% 
  unnest(summary) 

FTdata %>% 
  filter(sowing_number %in% c("Q148", "Q149", "Q236")) %>%
  mutate(days_to_flower = if_else(is.na(days_to_flower), 999L, days_to_flower),
         late = is.na(flowering_date)) %>% 
  group_by(late) %>% 
  tally() %>% 
  mutate(expected = c(0.75, 0.25)) %$%
  chisq.test(n, p = expected) %>% 
  broom::tidy()

(92-81.75)^2/81.75 + (17-27.25)^2/27.25

1-pchisq(5.14, 1)
  
###########################################################
### Linkage - Chi Squared goodness of fit 
###           (genotyping)
###            F2 Pop.     
### Batch 1    Q148, Q149  
### Batch 2    Q236       
###########################################################
FTdata %>% 
  filter(sowing_number %in% c("Q148", "Q149", "Q236")) %>%
  mutate(mutant = factor(mutant, levels = c("Wild-type segregant",
                                            "Heterozygous",
                                            "Homozygous")),
         late = is.na(flowering_date)) %>% 
  group_by(mutant, late) %>% 
  tally() %>% 
  ungroup() %>% 
  mutate(expected = c(0.25, 0.5, 0.25)) %$%
  chisq.test(n, p = expected) %>% 
  broom::tidy()

###########################################################
### Linkage - Summary table
###########################################################
FTdata %>% 
  filter(sowing_number %in% c("Q148", "Q149", "Q236")) %>%
  mutate(mutant = factor(mutant, levels = c("Wild-type segregant",
                                            "Heterozygous",
                                            "Homozygous"))) %>% 
  select(mutant, days_to_flower, node_num) %>% 
  group_by(mutant) %>% 
  summarise(mean_days = mean(days_to_flower), mean_nodes = mean(node_num),
            max_days = max(days_to_flower), max_nodes = max(node_num),
            min_days = min(days_to_flower), min_nodes = min(node_num)) %>% 
  unite(days_range, min_days, max_days, sep = "-") %>% 
  unite(nodes_range, min_nodes, max_nodes, sep = "-") %>% 
  right_join(linkage_tally %>% select(mutant, n)) %>% 
  select(mutant, n, mean_days, days_range, mean_nodes, nodes_range)
  
